@@ -354,7 +354,6 @@ class RESTAPI :
                 "summonerid" : "{summonerId}".format(summonerId=participant['summonerId']),
                 "assists" : int(participant['assists']),
                 "baronkills" : int(participant['baronKills']),
-                "bountylevel" : int(participant['bountyLevel']),
                 "champexperience" : int(participant['champExperience']),
                 "champlevel" : int(participant['champLevel']),
                 "championid" : int(participant['championId']),
@@ -364,7 +363,6 @@ class RESTAPI :
                 "damagedealttoturrets" : int(participant['damageDealtToTurrets']),
                 "damageselfmitigated" : int(participant['damageSelfMitigated']),
                 "deaths" : int(participant['deaths']),
-                "detectorwardsplaced" : int(participant['detectorWardsPlaced']),
                 "doublekills" : int(participant['doubleKills']),
                 "dragonkills" : int(participant['dragonKills']),
                 "firstbloodassist" : int(participant['firstBloodAssist']),
@@ -386,23 +384,13 @@ class RESTAPI :
                 "item4" : int(participant['item4']),
                 "item5" : int(participant['item5']),
                 "item6" : int(participant['item6']),
-                "itemspurchased" : int(participant['itemsPurchased']),
-                "killingsprees" : int(participant['killingSprees']),
                 "kills" : int(participant['kills']),
                 "lane" : "{lane}".format(lane=participant['lane']),
                 "largestcriticalstrike" : int(participant['largestCriticalStrike']),
-                "largestkillingspree" : int(participant['largestKillingSpree']),
-                "largestmultikill" : int(participant['largestMultiKill']),
-                "longesttimespentliving" : int(participant['longestTimeSpentLiving']),
                 "magicdamagedealt" : int(participant['magicDamageDealt']),
                 "magicdamagedealttochampions" : int(participant['magicDamageDealtToChampions']),
                 "magicdamagetaken" : int(participant['magicDamageTaken']),
                 "neutralminionskilled" : int(participant['neutralMinionsKilled']),
-                "nexuskills" : int(participant['nexusKills']),
-                "nexuslost" : int(participant['nexusLost']),
-                "nexustakedowns" : int(participant['nexusTakedowns']),
-                "objectivesstolen" : int(participant['objectivesStolen']),
-                "objectivesstolenassists" : int(participant['objectivesStolenAssists']),
                 "participantid" : int(participant['participantId']),
                 "pentakills" : int(participant['pentaKills']),
                 "physicaldamagedealt" : int(participant['physicalDamageDealt']),
@@ -422,14 +410,7 @@ class RESTAPI :
                 "rune6id" : int(runes[5]),
                 "runestyle1id" : int(styles[0]),
                 "runestyle2id" : int(styles[1]),
-                "sightwardsboughtingame" : int(participant['sightWardsBoughtInGame']),
-                "spell1casts" : int(participant['spell1Casts']),
-                "spell2casts" : int(participant['spell2Casts']),
-                "spell3casts" : int(participant['spell3Casts']),
-                "spell4casts" : int(participant['spell4Casts']),
-                "summoner1casts" : int(participant['summoner1Casts']),
                 "summoner1id" : int(participant['summoner1Id']),
-                "summoner2casts" : int(participant['summoner2Casts']),
                 "summoner2id" : int(participant['summoner2Id']),
                 "summonerlevel" : int(participant['summonerLevel']),
                 "summonername" : "{summonerName}".format(summonerName=participant['summonerName']),
@@ -437,7 +418,6 @@ class RESTAPI :
                 "teamid" : int(participant['teamId']),
                 "teamposition" : "{teamPosition}".format(teamPosition=participant['teamPosition']),
                 "timeccingothers" : int(participant['timeCCingOthers']),
-                "timeplayed" : int(participant['timePlayed']),
                 "totaldamagedealt" : int(participant['totalDamageDealt']),
                 "totaldamagedealttochampions" : int(participant['totalDamageDealtToChampions']),
                 "totaldamageshieldedonteammates" : int(participant['totalDamageShieldedOnTeammates']),
@@ -455,11 +435,6 @@ class RESTAPI :
                 "turretkills" : int(participant['turretKills']),
                 "turrettakedowns" : int(participant['turretTakedowns']),
                 "turretslost" : int(participant['turretsLost']),
-                "unrealkills" : int(participant['unrealKills']),
-                "visionscore" : int(participant['visionScore']),
-                "visionwardsboughtingame" : int(participant['visionWardsBoughtInGame']),
-                "wardskilled" : int(participant['wardsKilled']),
-                "wardsplaced" : int(participant['wardsPlaced']),
                 "win" : participant['win']
             }
         
